summaryrefslogtreecommitdiff
path: root/slideshow/source/inc/event.hxx
diff options
context:
space:
mode:
authorOliver Bolte <obo@openoffice.org>2005-04-22 12:31:02 +0000
committerOliver Bolte <obo@openoffice.org>2005-04-22 12:31:02 +0000
commit24fc662713cd0a31d886cff035a082231a979afa (patch)
tree9c8e8c7066d72e60443f2d6cc0e24547ee36bd25 /slideshow/source/inc/event.hxx
parent1469dfafb71cbc4bc6fb98b17c879da2e935e892 (diff)
INTEGRATION: CWS presfixes04 (1.3.16); FILE MERGED
2005/04/20 18:02:23 thb 1.3.16.1: #i47657# Changed Event interface, to better express the meaning of the isCharged() (former wasFired()) method; changed EventQueue and UserEventQueue to ignore events which are discharged; changed Impl_Presentation::notifySlideAnimationEnded to generate an interruptable delay, i.e. one that can be fired prematurely by user intervention; improved/clarified docs
Diffstat (limited to 'slideshow/source/inc/event.hxx')
-rw-r--r--slideshow/source/inc/event.hxx13
1 files changed, 9 insertions, 4 deletions
diff --git a/slideshow/source/inc/event.hxx b/slideshow/source/inc/event.hxx
index fd71f6e4f58f..b43c1ae8db3c 100644
--- a/slideshow/source/inc/event.hxx
+++ b/slideshow/source/inc/event.hxx
@@ -2,9 +2,9 @@
*
* $RCSfile: event.hxx,v $
*
- * $Revision: 1.3 $
+ * $Revision: 1.4 $
*
- * last change: $Author: vg $ $Date: 2005-03-10 13:54:06 $
+ * last change: $Author: obo $ $Date: 2005-04-22 13:30:33 $
*
* The Contents of this file are made available subject to the terms of
* either of the following licenses
@@ -84,11 +84,16 @@ namespace presentation
*/
virtual bool fire() = 0;
- /** Query whether this event has been fired.
+ /** Query whether this event is still charged, i.e. able
+ to fire.
+
+ Inactive events are ignored by the normal event
+ containers (EventQueue, UserEventQueue etc.), and no
+ explicit fire() is called upon them.
@return true, if this event has already been fired.
*/
- virtual bool wasFired() const = 0;
+ virtual bool isCharged() const = 0;
/** Query the activation time instant this event shall be
fired, if it was inserted at instant nCurrentTime into